==> gwyddion_2.44.orig.tar.xz: gwyddion-2.44/libgwydgets/gwydgettypes.h <==
/* This is a GENERATED file. */
/* Generated data (by glib-mkenums) */

#ifndef __GWYDGET_TYPES_H__
#define __GWYDGET_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

GType gwy_axis_scale_format_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_AXIS_SCALE_FORMAT (gwy_axis_scale_format_get_type())

GType gwy_3d_movement_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_3D_MOVEMENT (gwy_3d_movement_get_type())

GType gwy_3d_projection_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_3D_PROJECTION (gwy_3d_projection_get_type())

GType gwy_3d_visualization_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_3D_VISUALIZATION (gwy_3d_visualization_get_type())

GType gwy_3d_view_label_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_3D_VIEW_LABEL (gwy_3d_view_label_get_type())

GType gwy_units_placement_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_UNITS_PLACEMENT (gwy_units_placement_get_type())

GType gwy_hscale_style_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_HSCALE_STYLE (gwy_hscale_style_get_type())

GType gwy_graph_status_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_STATUS_TYPE (gwy_graph_status_type_get_type())

GType gwy_graph_grid_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_GRID_TYPE (gwy_graph_grid_type_get_type())

GType gwy_graph_point_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_POINT_TYPE (gwy_graph_point_type_get_type())

GType gwy_graph_curve_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_CURVE_TYPE (gwy_graph_curve_type_get_type())

GType gwy_graph_label_position_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_LABEL_POSITION (gwy_graph_label_position_get_type())

GType gwy_graph_model_export_style_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_MODEL_EXPORT_STYLE (gwy_graph_model_export_style_get_type())

GType gwy_layer_basic_range_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_LAYER_BASIC_RANGE_TYPE (gwy_layer_basic_range_type_get_type())

GType gwy_curve_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_CURVE_TYPE (gwy_curve_type_get_type())

GType gwy_curve_channel_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_CURVE_CHANNEL (gwy_curve_channel_get_type())

GType gwy_marker_operation_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_MARKER_OPERATION_TYPE (gwy_marker_operation_type_get_type())

GType gwy_data_view_layer_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DATA_VIEW_LAYER_TYPE (gwy_data_view_layer_type_get_type())

GType gwy_ticks_style_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_TICKS_STYLE (gwy_ticks_style_get_type())

GType gwy_grain_value_store_column_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAIN_VALUE_STORE_COLUMN (gwy_grain_value_store_column_get_type())

G_END_DECLS

#endif /* __GWYDGET_TYPES_H__ */

/* Generated data ends here */

==> gwyddion_2.49.orig.tar.xz: gwyddion-2.49/libgwydgets/gwydgettypes.h <==
/* This is a GENERATED file. */
/* Generated data (by glib-mkenums) */

#ifndef __GWYDGET_TYPES_H__
#define __GWYDGET_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

GType gwy_axis_scale_format_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_AXIS_SCALE_FORMAT (gwy_axis_scale_format_get_type())

GType gwy_3d_movement_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_3D_MOVEMENT (gwy_3d_movement_get_type())

GType gwy_3d_projection_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_3D_PROJECTION (gwy_3d_projection_get_type())

GType gwy_3d_visualization_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_3D_VISUALIZATION (gwy_3d_visualization_get_type())

GType gwy_3d_view_label_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_3D_VIEW_LABEL (gwy_3d_view_label_get_type())

GType gwy_units_placement_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_UNITS_PLACEMENT (gwy_units_placement_get_type())

GType gwy_hscale_style_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_HSCALE_STYLE (gwy_hscale_style_get_type())

GType gwy_graph_status_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_STATUS_TYPE (gwy_graph_status_type_get_type())

GType gwy_graph_grid_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_GRID_TYPE (gwy_graph_grid_type_get_type())

GType gwy_graph_point_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_POINT_TYPE (gwy_graph_point_type_get_type())

GType gwy_graph_curve_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_CURVE_TYPE (gwy_graph_curve_type_get_type())

GType gwy_graph_label_position_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_LABEL_POSITION (gwy_graph_label_position_get_type())

GType gwy_graph_model_export_style_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAPH_MODEL_EXPORT_STYLE (gwy_graph_model_export_style_get_type())

GType gwy_layer_basic_range_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_LAYER_BASIC_RANGE_TYPE (gwy_layer_basic_range_type_get_type())

GType gwy_curve_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_CURVE_TYPE (gwy_curve_type_get_type())

GType gwy_curve_channel_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_CURVE_CHANNEL (gwy_curve_channel_get_type())

GType gwy_marker_operation_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_MARKER_OPERATION_TYPE (gwy_marker_operation_type_get_type())

GType gwy_data_view_layer_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DATA_VIEW_LAYER_TYPE (gwy_data_view_layer_type_get_type())

GType gwy_ticks_style_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_TICKS_STYLE (gwy_ticks_style_get_type())

GType gwy_scale_mapping_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_SCALE_MAPPING_TYPE (gwy_scale_mapping_type_get_type())

GType gwy_grain_value_store_column_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_GRAIN_VALUE_STORE_COLUMN (gwy_grain_value_store_column_get_type())

G_END_DECLS

#endif /* __GWYDGET_TYPES_H__ */

/* Generated data ends here */
